# Welcome to Intake-Thredds' documentation!

Intake-Thredds provides a lightweight intake interface to [THREDDS](https://www.unidata.ucar.edu/software/tds/current/catalog/) data catalogs.

## Feedback

If you encounter any errors or problems with **intake-thredds**, please open an issue at the GitHub [main repository](http://github.com/intake/intake-thredds).

```{toctree}
---
maxdepth: 2
hidden:
---
tutorials/index.md
how-to/index.md
explanation/index.md
reference/index.md
changelog.md
```

```{toctree}
---
maxdepth: 1
caption: Contribute to Intake-Thredds
hidden:
---
contributing.md
```

```{toctree}
---
maxdepth: 1
caption: Community
hidden:
---
GitHub Repo <https://github.com/intake/intake-thredds>
GitHub discussions <https://github.com/intake-thredds/discussions>
```
